@@ -3,6 +3,7 @@
 """
 import json
 
+from django.contrib.admin.views.decorators import staff_member_required
 from django.http import HttpResponse
 
 import core_website_app.components.account_request.api as account_request_api
@@ -11,6 +12,7 @@ from core_main_app.commons import exceptions as main_exceptions
 from core_website_app.commons import exceptions
 
 
+@staff_member_required
 def accept_request(request):
     """
     Accepts a request and creates the user account
@@ -18,7 +20,7 @@ def accept_request(request):
     :return:
     """
     try:
-        request_id = request.POST['requestid']
+        request_id = request.POST["requestid"]
         account_request_from_api = account_request_api.get(request_id)
         account_request_api.accept(account_request_from_api)
         message = "Request Accepted"
@@ -27,9 +29,12 @@ def accept_request(request):
     except Exception as exception:
         raise exceptions.WebsiteAjaxError(str(exception))
 
-    return HttpResponse(json.dumps({"message": message}), content_type='application/json')
+    return HttpResponse(
+        json.dumps({"message": message}), content_type="application/json"
+    )
 
 
+@staff_member_required
 def deny_request(request):
     """
     Denies an account request
@@ -38,7 +43,7 @@ def deny_request(request):
     """
 
     try:
-        request_id = request.POST['requestid']
+        request_id = request.POST["requestid"]
         account_request_from_api = account_request_api.get(request_id)
         account_request_api.deny(account_request_from_api)
         message = "Request denied"
@@ -47,9 +52,12 @@ def deny_request(request):
     except Exception as exception:
         raise exceptions.WebsiteAjaxError(str(exception))
 
-    return HttpResponse(json.dumps({"message": message}), content_type='application/json')
+    return HttpResponse(
+        json.dumps({"message": message}), content_type="application/json"
+    )
 
 
+@staff_member_required
 def remove_message(request):
     """
     Remove a message from the list of messages
@@ -58,7 +66,7 @@ def remove_message(request):
     """
 
     try:
-        contact_message = contact_message_api.get(request.POST['messageid'])
+        contact_message = contact_message_api.get(request.POST["messageid"])
         contact_message_api.delete(contact_message)
         message = "Message deleted"
     except exceptions.WebsiteAjaxError as error:
@@ -66,9 +74,12 @@ def remove_message(request):
     except Exception as exception:
         message = str(exception)
 
-    return HttpResponse(json.dumps({"message": message}), content_type='application/json')
+    return HttpResponse(
+        json.dumps({"message": message}), content_type="application/json"
+    )
 
 
+@staff_member_required
 def account_request_count(request):
     """
 
@@ -76,8 +87,15 @@ def account_request_count(request):
     Returns:
 
     """
-    return HttpResponse(json.dumps({"count": account_request_api.get_count()}), content_type='application/json')
+    return HttpResponse(
+        json.dumps({"count": account_request_api.get_count()}),
+        content_type="application/json",
+    )
 
 
+@staff_member_required
 def contact_message_count(request):
-    return HttpResponse(json.dumps({"count": contact_message_api.get_count()}), content_type='application/json')
+    return HttpResponse(
+        json.dumps({"count": contact_message_api.get_count()}),
+        content_type="application/json",
+    )
